@@ -70,7 +70,8 @@ sub awx_grep_dlls {
         $ret->{mono} = delete $ret->{base};
     }
 
-    die "Configuration error: could not find libraries for this configuration"
+    die "Configuration error: could not find libraries for configuration: "
+        . join ' ', map "'$_'", $suff, $digits
       unless ( exists $ret->{core}{dll} and exists $ret->{core}{lib} )
           or ( exists $ret->{mono}{dll} and exists $ret->{mono}{lib} );
 
@@ -203,7 +204,7 @@ sub awx_get_package {
     return 'WinCE' if $INC{'Cross.pm'};
 
     SWITCH: {
-        local $_ = $Config{cc};
+        local $_ = $Config{ccname};
 
         /^cl/i  and $package = 'Win32_MSVC'  and last SWITCH;
         /^gcc/i and $package = 'Win32_MinGW' and last SWITCH;
